pub struct DMSCCacheStats {
pub hits: u64,
pub misses: u64,
pub entries: usize,
pub memory_usage_bytes: usize,
pub avg_hit_rate: f64,
pub hit_count: u64,
pub miss_count: u64,
pub eviction_count: u64,
}Expand description
Cache statistics
Fields
hits: u64misses: u64entries: usizememory_usage_bytes: usizeavg_hit_rate: f64hit_count: u64miss_count: u64eviction_count: u64Trait Implementations
Sourceimpl Clone for DMSCCacheStats
impl Clone for DMSCCacheStats
Sourcefn clone(&self) -> DMSCCacheStats
fn clone(&self) -> DMSCCacheStats
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DMSCCacheStats
impl Debug for DMSCCacheStats
Sourceimpl Default for DMSCCacheStats
impl Default for DMSCCacheStats
Sourceimpl<'de> Deserialize<'de> for DMSCCacheStats
impl<'de> Deserialize<'de> for DMSCCacheStats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'py> IntoPyObject<'py> for DMSCCacheStats
impl<'py> IntoPyObject<'py> for DMSCCacheStats
Sourcetype Target = DMSCCacheStats
type Target = DMSCCacheStats
The Python output type
Sourcetype Output = Bound<'py, <DMSCCacheStats as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <DMSCCacheStats as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for DMSCCacheStats
impl PyClass for DMSCCacheStats
Sourceimpl PyClassImpl for DMSCCacheStats
impl PyClassImpl for DMSCCacheStats
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Cache statistics
const RAW_DOC: &'static CStr = /// Cache statistics
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<DMSCCacheStats>
type ThreadChecker = SendablePyClass<DMSCCacheStats>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for DMSCCacheStats
impl PyClassNewTextSignature for DMSCCacheStats
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<DMSCCacheStats> for PyClassImplCollector<DMSCCacheStats>
impl PyMethods<DMSCCacheStats> for PyClassImplCollector<DMSCCacheStats>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for DMSCCacheStats
impl PyTypeInfo for DMSCCacheStats
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for DMSCCacheStats
impl Serialize for DMSCCacheStats
impl Copy for DMSCCacheStats
impl DerefToPyAny for DMSCCacheStats
impl ExtractPyClassWithClone for DMSCCacheStats